// Copyright 2008-2014 severally by the contributors
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package net.sf.practicalxml.xpath.function;

import java.util.List;

import net.sf.practicalxml.xpath.AbstractStringFunction;


/**
 *  Converts the string value of its argument to lowercase, using a locale-aware
 *  conversion.
 */
public class Lowercase
extends AbstractStringFunction
{
    public Lowercase()
    {
        super(Constants.COMMON_NS_URI, "lowercase", 1);
    }

    @Override
    public Object evaluate(String value, List<?> args)
    {
        return value.toLowerCase();
    }
}
